Capybara
========

Capybara helps you test web applications by simulating how a real user would
interact with your app. It is agnostic about the driver running your tests and
comes with Werkzeug and Selenium support built in.

|build|_

.. |build| image:: https://secure.travis-ci.org/elliterate/capybara.py.svg?branch=master
.. _build: http://travis-ci.org/elliterate/capybara.py

Documentation
~~~~~~~~~~~~~

See https://elliterate.github.io/capybara.py/.

Credits
~~~~~~~

Ported to Python by `Ian Lesperance`_, from the `original Ruby library`_ by `Jonas Nicklas`_.

.. _Ian Lesperance: https://github.com/elliterate
.. _Jonas Nicklas: https://github.com/jnicklas
.. _original Ruby library: https://github.com/jnicklas/capybara
